@@ -61,7 +61,8 @@ class AbstractSICConnector(object):
                                          'memory_set_interactant', 'memory_set_dialog_history',
                                          'memory_get_dialog_history_all',
                                          'memory_delete_interactant', 'memory_delete_all_interactants',
-                                         'memory_get_move_history', 'memory_set_move_history'],
+                                         'memory_get_move_history', 'memory_set_move_history',
+                                         'memory_get_topics_of_interest', 'memory_set_topics_of_interest'],
             self.device_types['speaker']: ['audio_language', 'action_say', 'action_speech_param', 'action_say_animated', 'action_play_audio',
                                            'action_stop_talking', 'action_load_audio', 'action_clear_loaded_audio',
                                            'text_to_speech', 'tts_key', 'tts_voice'],
@@ -659,6 +660,12 @@ class AbstractSICConnector(object):
     def set_move_history(self, interactant_id: str, move: str):
         self.__send('memory_set_move_history', f'{interactant_id};{move}')
 
+    def get_topics_of_interest(self, interactant_id: str):
+        self.__send('memory_get_topics_of_interest', interactant_id)
+
+    def set_topics_of_interest(self, interactant_id: str, topics: list):
+        self.__send('memory_set_topics_of_interest', f'{interactant_id};{dumps(topics)}')
+
 
     ###########################
     # Browser Actions         #
