@@ -728,15 +728,25 @@ class BasicSICConnector(AbstractSICConnector):
         self.__process_action(super(BasicSICConnector, self).delete_all_interactants,
                               callback=callback, event='AllInteractantsDeleted', sync=sync, load=load)
 
+    def get_move_history(self, interactant_id: str,
+                         callback: callable = None, sync: bool = True, load: bool = False) -> None:
+        self.__process_action(super(BasicSICConnector, self).get_move_history, interactant_id,
+                              callback=callback, event='MoveHistory', sync=sync, load=load, memory=True)
+
     def set_move_history(self, interactant_id: str, move: str,
                          callback: callable = None, sync: bool = True, load: bool = False) -> None:
         self.__process_action(super(BasicSICConnector, self).set_move_history, interactant_id, move,
                               callback=callback, event='MoveHistorySet', sync=sync, load=load)
 
-    def get_move_history(self, interactant_id: str,
+    def get_topics_of_interest(self, interactant_id: str,
                          callback: callable = None, sync: bool = True, load: bool = False) -> None:
-        self.__process_action(super(BasicSICConnector, self).get_move_history, interactant_id,
-                              callback=callback, event='MoveHistory', sync=sync, load=load, memory=True)
+        self.__process_action(super(BasicSICConnector, self).get_topics_of_interest, interactant_id,
+                              callback=callback, event='TopicsOfInterest', sync=sync, load=load, memory=True)
+
+    def set_topics_of_interest(self, interactant_id: str, topics: list,
+                         callback: callable = None, sync: bool = True, load: bool = False) -> None:
+        self.__process_action(super(BasicSICConnector, self).set_topics_of_interest, interactant_id, topics,
+                              callback=callback, event='TopicsOfInterestSet', sync=sync, load=load)
 
     ###########################
     # Listeners Management  #
